@@ -1,12 +1,4 @@
-(function (factory) {
-    if (typeof define === 'function' && define.amd) {
-        // AMD. Register as anonymous module.
-        define(['jquery'], factory);
-    } else {
-        // Browser globals.
-        window.djdt = factory(jQuery);
-    }
-}(function ($) {
+(function ($, publicAPI) {
     var djdt = {
         handleDragged: false,
         events: {
@@ -23,10 +15,10 @@
                 current = $('#djDebug #' + this.className);
                 if (current.is(':visible')) {
                     $(document).trigger('close.djDebug');
-                    $(this).parent().removeClass('active');
+                    $(this).parent().removeClass('djdt-active');
                 } else {
-                    $('.panelContent').hide(); // Hide any that are already open
-                    var inner = current.find('.djDebugPanelContent .scroll'),
+                    $('.djdt-panelContent').hide(); // Hide any that are already open
+                    var inner = current.find('.djDebugPanelContent .djdt-scroll'),
                         store_id = $('#djDebug').data('store-id'),
                         render_panel_url = $('#djDebug').data('render-panel-url');
                     if (store_id !== '' && inner.children().length === 0) {
@@ -42,19 +34,19 @@
                             inner.prev().remove();  // Remove AJAX loader
                             inner.html(data);
                         }).fail(function(xhr){
-                            var message = '<div class="djDebugPanelTitle"><a class="djDebugClose djDebugBack" href="">Back</a><h3>'+xhr.status+': '+xhr.statusText+'</h3></div>';
+                            var message = '<div class="djDebugPanelTitle"><a class="djDebugClose djDebugBack" href=""></a><h3>'+xhr.status+': '+xhr.statusText+'</h3></div>';
                             $('#djDebugWindow').html(message).show();
                         });
                     }
                     current.show();
-                    $('#djDebugToolbar li').removeClass('active');
-                    $(this).parent().addClass('active');
+                    $('#djDebugToolbar li').removeClass('djdt-active');
+                    $(this).parent().addClass('djdt-active');
                 }
                 return false;
             });
             $(document).on('click', '#djDebug a.djDebugClose', function() {
                 $(document).trigger('close.djDebug');
-                $('#djDebugToolbar li').removeClass('active');
+                $('#djDebugToolbar li').removeClass('djdt-active');
                 return false;
             });
             $(document).on('click', '#djDebug .djDebugPanelButton input[type=checkbox]', function() {
@@ -87,7 +79,7 @@
                 $.ajax(ajax_data).done(function(data){
                     $('#djDebugWindow').html(data).show();
                 }).fail(function(xhr){
-                        var message = '<div class="djDebugPanelTitle"><a class="djDebugClose djDebugBack" href="">Back</a><h3>'+xhr.status+': '+xhr.statusText+'</h3></div>';
+                        var message = '<div class="djDebugPanelTitle"><a class="djDebugClose djDebugBack" href=""></a><h3>'+xhr.status+': '+xhr.statusText+'</h3></div>';
                         $('#djDebugWindow').html(message).show();
                 });
 
@@ -140,19 +132,32 @@
             });
             var handle = $('#djDebugToolbarHandle');
             $('#djShowToolBarButton').on('mousedown', function (event) {
-                var baseY = handle.offset().top - event.pageY;
+                var startPageY = event.pageY;
+                var baseY = handle.offset().top - startPageY;
+                var windowHeight = $(window).height();
                 $(document).on('mousemove.djDebug', function (event) {
-                    var offset = handle.offset();
-                    offset.top = baseY + event.pageY;
-                    handle.offset(offset);
-                    djdt.handleDragged = true;
+                    // Chrome can send spurious mousemove events, so don't do anything unless the
+                    // cursor really moved.  Otherwise, it will be impossible to expand the toolbar
+                    // due to djdt.handleDragged being set to true.
+                    if (djdt.handleDragged || event.pageY != startPageY) {
+                        var top = baseY + event.clientY;
+                        
+                        if (top < 0) {
+                            top = 0;
+                        } else if (top + handle.height() > windowHeight) {
+                            top = windowHeight - handle.height();
+                        }
+                        
+                        handle.css({top: top});
+                        djdt.handleDragged = true;
+                    }
                 });
                 return false;
             });
             $(document).on('mouseup', function () {
                 $(document).off('mousemove.djDebug');
                 if (djdt.handleDragged) {
-                    var top = handle.offset().top;
+                    var top = handle.offset().top - window.pageYOffset;
                     djdt.cookie.set('djdttop', top, {
                         path: '/',
                         expires: 10
@@ -170,9 +175,9 @@
                     return;
                 }
                 // If a panel is open, close that
-                if ($('.panelContent').is(':visible')) {
-                    $('.panelContent').hide();
-                    $('#djDebugToolbar li').removeClass('active');
+                if ($('.djdt-panelContent').is(':visible')) {
+                    $('.djdt-panelContent').hide();
+                    $('#djDebugToolbar li').removeClass('djdt-active');
                     return;
                 }
                 // Otherwise, just minimize the toolbar
@@ -204,8 +209,8 @@
             // close any sub panels
             $('#djDebugWindow').hide();
             // close all panels
-            $('.panelContent').hide();
-            $('#djDebugToolbar li').removeClass('active');
+            $('.djdt-panelContent').hide();
+            $('#djDebugToolbar li').removeClass('djdt-active');
             // finally close toolbar
             $('#djDebugToolbar').hide('fast');
             $('#djDebugToolbarHandle').show();
@@ -282,6 +287,11 @@
             }
         }
     };
+    $.extend(publicAPI, {
+        show_toolbar: djdt.show_toolbar,
+        hide_toolbar: djdt.hide_toolbar,
+        close: djdt.close,
+        cookie: djdt.cookie
+    });
     $(document).ready(djdt.init);
-    return djdt;
-}));
+})(djdt.jQuery, djdt);
